@@ -2,7 +2,7 @@
 package Tapper::Reports::DPath::Mason;
 our $AUTHORITY = 'cpan:TAPPER';
 # ABSTRACT: Mix DPath into Mason templates
-$Tapper::Reports::DPath::Mason::VERSION = '5.0.4';
+$Tapper::Reports::DPath::Mason::VERSION = '5.0.5';
 use 5.010;
         use Moose;
 
@@ -10,6 +10,8 @@ use 5.010;
         use Cwd 'cwd';
         use Data::Dumper;
         use File::ShareDir 'module_dir';
+        use Moose::Exporter;
+        Moose::Exporter->setup_import_methods(as_is => [ 'render' ] );
 
         has debug           => ( is => 'rw');
         has puresqlabstract => ( is => 'rw', default => 0);
@@ -142,7 +144,7 @@ Tapper Team <tapper-ops@amazon.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2020 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2024 by Advanced Micro Devices, Inc.
 
 This is free software, licensed under:
 
